package com.ruoyi.system.service;

import java.util.List;

import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.system.domain.InvestigateUser;

/**
 * 考察人员信息Service接口
 * 
 * @author ruoyi
 * @date 2023-10-10
 */
public interface IInvestigateUserService 
{
    /**
     * 查询考察人员信息
     * 
     * @param id 考察人员信息主键
     * @return 考察人员信息
     */
    public InvestigateUser selectInvestigateUserById(Long id);

    /**
     * 查询考察人员信息列表
     * 
     * @param investigateUser 考察人员信息
     * @return 考察人员信息集合
     */
    public List<InvestigateUser> selectInvestigateUserList(InvestigateUser investigateUser);

    /**
     * 新增考察人员信息
     * 
     * @param investigateUser 考察人员信息
     * @return 结果
     */
    public int insertInvestigateUser(InvestigateUser investigateUser);

    /**
     * 修改考察人员信息
     * 
     * @param investigateUser 考察人员信息
     * @return 结果
     */
    public int updateInvestigateUser(InvestigateUser investigateUser);

    /**
     * 批量删除考察人员信息
     * 
     * @param ids 需要删除的考察人员信息主键集合
     * @return 结果
     */
    public int deleteInvestigateUserByIds(Long[] ids);

    /**
     * 删除考察人员信息信息
     * 
     * @param id 考察人员信息主键
     * @return 结果
     */
    public int deleteInvestigateUserById(Long id);

    /**
     * 给对应考察团发送密码短信
     * @param investigateUser
     * @return
     */
    AjaxResult sendSmsInvestigateTable(InvestigateUser investigateUser);
}
